====================
plone.jsonapi.routes
====================

Welcome to `plone.jsonapi.routes` documentation. This documentation is divided
in different parts. I recommend that you get started with :doc:`installation`
and then head over to the :doc:`quickstart`. Please check out the :doc:`api`
documentation for internals about `plone.jsonapi.routes`.


Table of Contents:

.. toctree::
   :maxdepth: 2

   installation
   quickstart
   api
   customizing
   crud
   links
   CONTRIBUTORS
   LICENSE
   HISTORY
